# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_conditions/v1/tick_conditions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/tick_conditions/v1/tick_conditions.proto\x12-systemathics.apis.services.tick_conditions.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x8a\x01\n\x15TickConditionsRequest\x12\x42\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierH\x00\x12\x12\n\x08\x65xchange\x18\x02 \x01(\tH\x00\x12\x10\n\x06source\x18\x03 \x01(\x05H\x00\x42\x07\n\x05value\"`\n\x16TickConditionsResponse\x12\x46\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x38.systemathics.apis.services.tick_conditions.v1.Condition\"b\n\tCondition\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x0f\n\x07regular\x18\x04 \x01(\x08\x12\x0f\n\x07\x61uction\x18\x05 \x01(\x08\x32\xb7\x01\n\x15TickConditionsService\x12\x9d\x01\n\x0eTickConditions\x12\x44.systemathics.apis.services.tick_conditions.v1.TickConditionsRequest\x1a\x45.systemathics.apis.services.tick_conditions.v1.TickConditionsResponseb\x06proto3')



_TICKCONDITIONSREQUEST = DESCRIPTOR.message_types_by_name['TickConditionsRequest']
_TICKCONDITIONSRESPONSE = DESCRIPTOR.message_types_by_name['TickConditionsResponse']
_CONDITION = DESCRIPTOR.message_types_by_name['Condition']
TickConditionsRequest = _reflection.GeneratedProtocolMessageType('TickConditionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsRequest)
  })
_sym_db.RegisterMessage(TickConditionsRequest)

TickConditionsResponse = _reflection.GeneratedProtocolMessageType('TickConditionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsResponse)
  })
_sym_db.RegisterMessage(TickConditionsResponse)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

_TICKCONDITIONSSERVICE = DESCRIPTOR.services_by_name['TickConditionsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKCONDITIONSREQUEST._serialized_start=170
  _TICKCONDITIONSREQUEST._serialized_end=308
  _TICKCONDITIONSRESPONSE._serialized_start=310
  _TICKCONDITIONSRESPONSE._serialized_end=406
  _CONDITION._serialized_start=408
  _CONDITION._serialized_end=506
  _TICKCONDITIONSSERVICE._serialized_start=509
  _TICKCONDITIONSSERVICE._serialized_end=692
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/identifier.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/type/shared/v1/identifier.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\"^\n\nIdentifier\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12.\n\x08provider\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueb\x06proto3')



_IDENTIFIER = DESCRIPTOR.message_types_by_name['Identifier']
Identifier = _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIER,
  '__module__' : 'systemathics.apis.type.shared.v1.identifier_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Identifier)
  })
_sym_db.RegisterMessage(Identifier)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IDENTIFIER._serialized_start=119
  _IDENTIFIER._serialized_end=213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_raw.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import identifier_and_level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__and__level__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import raw_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_raw__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v1/tick_raw.proto\x12\"systemathics.apis.services.tick.v1\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a;systemathics/apis/type/shared/v1/identifier_and_level.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a*systemathics/apis/type/shared/v1/raw.proto\"\x9f\x01\n\x0eTickRawRequest\x12I\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.type.shared.v1.IdentifierAndLevel\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\x8d\x01\n\x0fTickRawResponse\x12\x34\n\x03raw\x18\x01 \x01(\x0b\x32%.systemathics.apis.type.shared.v1.RawH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x86\x01\n\x0eTickRawService\x12t\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v1.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v1.TickRawResponse0\x01\x62\x06proto3')



_TICKRAWREQUEST = DESCRIPTOR.message_types_by_name['TickRawRequest']
_TICKRAWRESPONSE = DESCRIPTOR.message_types_by_name['TickRawResponse']
TickRawRequest = _reflection.GeneratedProtocolMessageType('TickRawRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawRequest)
  })
_sym_db.RegisterMessage(TickRawRequest)

TickRawResponse = _reflection.GeneratedProtocolMessageType('TickRawResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse)
  })
_sym_db.RegisterMessage(TickRawResponse)

_TICKRAWSERVICE = DESCRIPTOR.services_by_name['TickRawService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKRAWREQUEST._serialized_start=338
  _TICKRAWREQUEST._serialized_end=497
  _TICKRAWRESPONSE._serialized_start=500
  _TICKRAWRESPONSE._serialized_end=641
  _TICKRAWSERVICE._serialized_start=644
  _TICKRAWSERVICE._serialized_end=778
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/side.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+systemathics/apis/type/shared/v1/side.proto\x12 systemathics.apis.type.shared.v1*8\n\x04Side\x12\x14\n\x10SIDE_UNSPECIFIED\x10\x00\x12\x0c\n\x08SIDE_BID\x10\x01\x12\x0c\n\x08SIDE_ASK\x10\x02\x62\x06proto3')

_SIDE = DESCRIPTOR.enum_types_by_name['Side']
Side = enum_type_wrapper.EnumTypeWrapper(_SIDE)
SIDE_UNSPECIFIED = 0
SIDE_BID = 1
SIDE_ASK = 2


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SIDE._serialized_start=81
  _SIDE._serialized_end=137
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import identifier_and_level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__and__level__pb2
from systemathics.apis.type.shared.v1 import market_fields_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2
from systemathics.apis.type.shared.v1 import mbl_market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mbl__market__book__updates__pb2
from systemathics.apis.type.shared.v1 import mbo_market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mbo__market__book__updates__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5systemathics/apis/services/tick/v1/tick_updates.proto\x12\"systemathics.apis.services.tick.v1\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a;systemathics/apis/type/shared/v1/identifier_and_level.proto\x1a<systemathics/apis/type/shared/v1/market_fields_updates.proto\x1a>systemathics/apis/type/shared/v1/mbl_market_book_updates.proto\x1a>systemathics/apis/type/shared/v1/mbo_market_book_updates.proto\"\xb7\x01\n\x12TickUpdatesRequest\x12I\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.type.shared.v1.IdentifierAndLevel\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"\xd4\x02\n\x13TickUpdatesResponse\x12O\n\x0e\x66ields_updates\x18\x01 \x01(\x0b\x32\x35.systemathics.apis.type.shared.v1.MarketFieldsUpdatesH\x00\x12R\n\x10mbl_book_updates\x18\x02 \x01(\x0b\x32\x36.systemathics.apis.type.shared.v1.MblMarketBookUpdatesH\x00\x12R\n\x10mbo_book_updates\x18\x03 \x01(\x0b\x32\x36.systemathics.apis.type.shared.v1.MboMarketBookUpdatesH\x00\x12\x39\n\x07mapping\x18\x04 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x97\x01\n\x12TickUpdatesService\x12\x80\x01\n\x0bTickUpdates\x12\x36.systemathics.apis.services.tick.v1.TickUpdatesRequest\x1a\x37.systemathics.apis.services.tick.v1.TickUpdatesResponse0\x01\x62\x06proto3')



_TICKUPDATESREQUEST = DESCRIPTOR.message_types_by_name['TickUpdatesRequest']
_TICKUPDATESRESPONSE = DESCRIPTOR.message_types_by_name['TickUpdatesResponse']
TickUpdatesRequest = _reflection.GeneratedProtocolMessageType('TickUpdatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesRequest)
  })
_sym_db.RegisterMessage(TickUpdatesRequest)

TickUpdatesResponse = _reflection.GeneratedProtocolMessageType('TickUpdatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesResponse)
  })
_sym_db.RegisterMessage(TickUpdatesResponse)

_TICKUPDATESSERVICE = DESCRIPTOR.services_by_name['TickUpdatesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKUPDATESREQUEST._serialized_start=488
  _TICKUPDATESREQUEST._serialized_end=671
  _TICKUPDATESRESPONSE._serialized_start=674
  _TICKUPDATESRESPONSE._serialized_end=1014
  _TICKUPDATESSERVICE._serialized_start=1017
  _TICKUPDATESSERVICE._serialized_end=1168
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import quote_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_quote__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/limit.proto\x12 systemathics.apis.type.shared.v1\x1a,systemathics/apis/type/shared/v1/quote.proto\"l\n\x05Limit\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\r\x12\x37\n\x06quotes\x18\x04 \x03(\x0b\x32\'.systemathics.apis.type.shared.v1.Quoteb\x06proto3')



_LIMIT = DESCRIPTOR.message_types_by_name['Limit']
Limit = _reflection.GeneratedProtocolMessageType('Limit', (_message.Message,), {
  'DESCRIPTOR' : _LIMIT,
  '__module__' : 'systemathics.apis.type.shared.v1.limit_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Limit)
  })
_sym_db.RegisterMessage(Limit)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIMIT._serialized_start=128
  _LIMIT._serialized_end=236
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/topology/v1/topologies.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7systemathics/apis/services/topology/v1/topologies.proto\x12&systemathics.apis.services.topology.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a,systemathics/apis/type/shared/v1/level.proto\"\xb7\x02\n\x11TopologiesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x36\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\x12P\n\x0bgranularity\x18\x03 \x01(\x0e\x32;.systemathics.apis.services.topology.v1.TopologyGranularity\x12*\n\x05start\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"f\n\rTopologyEntry\x12 \n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x1e\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12\x13\n\x0bticks_count\x18\x03 \x01(\x04\"n\n\x12TopologiesResponse\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.topology.v1.TopologyEntry\x12\x10\n\x08has_more\x18\x02 \x01(\x08*\xe2\x01\n\x13TopologyGranularity\x12$\n TOPOLOGY_GRANULARITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTOPOLOGY_GRANULARITY_DAILY\x10\x01\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_WEEKLY\x10\x02\x12 \n\x1cTOPOLOGY_GRANULARITY_MONTHLY\x10\x03\x12!\n\x1dTOPOLOGY_GRANULARITY_QUATERLY\x10\x04\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_YEARLY\x10\x05\x32\x99\x01\n\x11TopologiesService\x12\x83\x01\n\nTopologies\x12\x39.systemathics.apis.services.topology.v1.TopologiesRequest\x1a:.systemathics.apis.services.topology.v1.TopologiesResponseb\x06proto3')

_TOPOLOGYGRANULARITY = DESCRIPTOR.enum_types_by_name['TopologyGranularity']
TopologyGranularity = enum_type_wrapper.EnumTypeWrapper(_TOPOLOGYGRANULARITY)
TOPOLOGY_GRANULARITY_UNSPECIFIED = 0
TOPOLOGY_GRANULARITY_DAILY = 1
TOPOLOGY_GRANULARITY_WEEKLY = 2
TOPOLOGY_GRANULARITY_MONTHLY = 3
TOPOLOGY_GRANULARITY_QUATERLY = 4
TOPOLOGY_GRANULARITY_YEARLY = 5


_TOPOLOGIESREQUEST = DESCRIPTOR.message_types_by_name['TopologiesRequest']
_TOPOLOGYENTRY = DESCRIPTOR.message_types_by_name['TopologyEntry']
_TOPOLOGIESRESPONSE = DESCRIPTOR.message_types_by_name['TopologiesResponse']
TopologiesRequest = _reflection.GeneratedProtocolMessageType('TopologiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESREQUEST,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesRequest)
  })
_sym_db.RegisterMessage(TopologiesRequest)

TopologyEntry = _reflection.GeneratedProtocolMessageType('TopologyEntry', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYENTRY,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologyEntry)
  })
_sym_db.RegisterMessage(TopologyEntry)

TopologiesResponse = _reflection.GeneratedProtocolMessageType('TopologiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESRESPONSE,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesResponse)
  })
_sym_db.RegisterMessage(TopologiesResponse)

_TOPOLOGIESSERVICE = DESCRIPTOR.services_by_name['TopologiesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOPOLOGYGRANULARITY._serialized_start=783
  _TOPOLOGYGRANULARITY._serialized_end=1009
  _TOPOLOGIESREQUEST._serialized_start=253
  _TOPOLOGIESREQUEST._serialized_end=564
  _TOPOLOGYENTRY._serialized_start=566
  _TOPOLOGYENTRY._serialized_end=668
  _TOPOLOGIESRESPONSE._serialized_start=670
  _TOPOLOGIESRESPONSE._serialized_end=780
  _TOPOLOGIESSERVICE._serialized_start=1012
  _TOPOLOGIESSERVICE._serialized_end=1165
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/sustainability/v1/sustainability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsystemathics/apis/services/sustainability/v1/sustainability.proto\x12,systemathics.apis.services.sustainability.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"Y\n\x15SustainabilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\"d\n\x16SustainabilityResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.sustainability.v1.Sustainability\"\x8a\x01\n\x0eSustainability\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0b\n\x03min\x18\x06 \x01(\x01\x12\x0b\n\x03max\x18\x07 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t2\xb5\x01\n\x15SustainabilityService\x12\x9b\x01\n\x0eSustainability\x12\x43.systemathics.apis.services.sustainability.v1.SustainabilityRequest\x1a\x44.systemathics.apis.services.sustainability.v1.SustainabilityResponseb\x06proto3')



_SUSTAINABILITYREQUEST = DESCRIPTOR.message_types_by_name['SustainabilityRequest']
_SUSTAINABILITYRESPONSE = DESCRIPTOR.message_types_by_name['SustainabilityResponse']
_SUSTAINABILITY = DESCRIPTOR.message_types_by_name['Sustainability']
SustainabilityRequest = _reflection.GeneratedProtocolMessageType('SustainabilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYREQUEST,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityRequest)
  })
_sym_db.RegisterMessage(SustainabilityRequest)

SustainabilityResponse = _reflection.GeneratedProtocolMessageType('SustainabilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityResponse)
  })
_sym_db.RegisterMessage(SustainabilityResponse)

Sustainability = _reflection.GeneratedProtocolMessageType('Sustainability', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITY,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.Sustainability)
  })
_sym_db.RegisterMessage(Sustainability)

_SUSTAINABILITYSERVICE = DESCRIPTOR.services_by_name['SustainabilityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUSTAINABILITYREQUEST._serialized_start=166
  _SUSTAINABILITYREQUEST._serialized_end=255
  _SUSTAINABILITYRESPONSE._serialized_start=257
  _SUSTAINABILITYRESPONSE._serialized_end=357
  _SUSTAINABILITY._serialized_start=360
  _SUSTAINABILITY._serialized_end=498
  _SUSTAINABILITYSERVICE._serialized_start=501
  _SUSTAINABILITYSERVICE._serialized_end=682
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/market_fields_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import field_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/type/shared/v1/market_fields_updates.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-systemathics/apis/type/shared/v1/action.proto\x1a,systemathics/apis/type/shared/v1/field.proto\"\xab\x01\n\x13MarketFieldsUpdates\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05reset\x18\x03 \x01(\x08\x12\x44\n\x07updates\x18\x04 \x03(\x0b\x32\x33.systemathics.apis.type.shared.v1.MarketFieldUpdate\"\xd4\x01\n\x11MarketFieldUpdate\x12\x38\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.Action\x12\x36\n\x05\x66ield\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Field\x12\x14\n\nlong_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x05 \x01(\tH\x00\x42\x07\n\x05valueb\x06proto3')



_MARKETFIELDSUPDATES = DESCRIPTOR.message_types_by_name['MarketFieldsUpdates']
_MARKETFIELDUPDATE = DESCRIPTOR.message_types_by_name['MarketFieldUpdate']
MarketFieldsUpdates = _reflection.GeneratedProtocolMessageType('MarketFieldsUpdates', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDSUPDATES,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldsUpdates)
  })
_sym_db.RegisterMessage(MarketFieldsUpdates)

MarketFieldUpdate = _reflection.GeneratedProtocolMessageType('MarketFieldUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDUPDATE,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldUpdate)
  })
_sym_db.RegisterMessage(MarketFieldUpdate)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MARKETFIELDSUPDATES._serialized_start=257
  _MARKETFIELDSUPDATES._serialized_end=428
  _MARKETFIELDUPDATE._serialized_start=431
  _MARKETFIELDUPDATE._serialized_end=643
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__updates__pb2
from systemathics.apis.type.shared.v1 import book_data_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/services/tick/v1/tick_book.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a\x33systemathics/apis/type/shared/v1/book_updates.proto\x1a\x30systemathics/apis/type/shared/v1/book_data.proto\"\xb7\x02\n\x0fTickBookRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x43\n\x0c\x62ook_updates\x18\x02 \x01(\x0e\x32-.systemathics.apis.type.shared.v1.BookUpdates\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\x12.\n\tmax_depth\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x14\n\x0c\x63ontributors\x18\x06 \x01(\x08\"\x94\x01\n\x10TickBookResponse\x12:\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32*.systemathics.apis.type.shared.v1.BookDataH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x8a\x01\n\x0fTickBookService\x12w\n\x08TickBook\x12\x33.systemathics.apis.services.tick.v1.TickBookRequest\x1a\x34.systemathics.apis.services.tick.v1.TickBookResponse0\x01\x62\x06proto3')



_TICKBOOKREQUEST = DESCRIPTOR.message_types_by_name['TickBookRequest']
_TICKBOOKRESPONSE = DESCRIPTOR.message_types_by_name['TickBookResponse']
TickBookRequest = _reflection.GeneratedProtocolMessageType('TickBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOOKREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickBookRequest)
  })
_sym_db.RegisterMessage(TickBookRequest)

TickBookResponse = _reflection.GeneratedProtocolMessageType('TickBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOOKRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickBookResponse)
  })
_sym_db.RegisterMessage(TickBookResponse)

_TICKBOOKSERVICE = DESCRIPTOR.services_by_name['TickBookService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKBOOKREQUEST._serialized_start=407
  _TICKBOOKREQUEST._serialized_end=718
  _TICKBOOKRESPONSE._serialized_start=721
  _TICKBOOKRESPONSE._serialized_end=869
  _TICKBOOKSERVICE._serialized_start=872
  _TICKBOOKSERVICE._serialized_end=1010
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_vwap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/services/daily/v1/daily_vwap.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xad\x01\n\x11\x44\x61ilyVwapsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"R\n\x12\x44\x61ilyVwapsResponse\x12<\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32..systemathics.apis.services.daily.v1.DailyVwap\"Z\n\tDailyVwap\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x92\x01\n\x11\x44\x61ilyVwapsService\x12}\n\nDailyVwaps\x12\x36.systemathics.apis.services.daily.v1.DailyVwapsRequest\x1a\x37.systemathics.apis.services.daily.v1.DailyVwapsResponseb\x06proto3')



_DAILYVWAPSREQUEST = DESCRIPTOR.message_types_by_name['DailyVwapsRequest']
_DAILYVWAPSRESPONSE = DESCRIPTOR.message_types_by_name['DailyVwapsResponse']
_DAILYVWAP = DESCRIPTOR.message_types_by_name['DailyVwap']
DailyVwapsRequest = _reflection.GeneratedProtocolMessageType('DailyVwapsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAPSREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwapsRequest)
  })
_sym_db.RegisterMessage(DailyVwapsRequest)

DailyVwapsResponse = _reflection.GeneratedProtocolMessageType('DailyVwapsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAPSRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwapsResponse)
  })
_sym_db.RegisterMessage(DailyVwapsResponse)

DailyVwap = _reflection.GeneratedProtocolMessageType('DailyVwap', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAP,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwap)
  })
_sym_db.RegisterMessage(DailyVwap)

_DAILYVWAPSSERVICE = DESCRIPTOR.services_by_name['DailyVwapsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYVWAPSREQUEST._serialized_start=221
  _DAILYVWAPSREQUEST._serialized_end=394
  _DAILYVWAPSRESPONSE._serialized_start=396
  _DAILYVWAPSRESPONSE._serialized_end=478
  _DAILYVWAP._serialized_start=480
  _DAILYVWAP._serialized_end=570
  _DAILYVWAPSSERVICE._serialized_start=573
  _DAILYVWAPSSERVICE._serialized_end=719
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/level.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/level.proto\x12 systemathics.apis.type.shared.v1*K\n\x05Level\x12\x15\n\x11LEVEL_UNSPECIFIED\x10\x00\x12\x10\n\x0cLEVEL_TRADES\x10\x01\x12\x19\n\x15LEVEL_TRADES_AND_BOOK\x10\x02\x62\x06proto3')

_LEVEL = DESCRIPTOR.enum_types_by_name['Level']
Level = enum_type_wrapper.EnumTypeWrapper(_LEVEL)
LEVEL_UNSPECIFIED = 0
LEVEL_TRADES = 1
LEVEL_TRADES_AND_BOOK = 2


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LEVEL._serialized_start=82
  _LEVEL._serialized_end=157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v1/intraday_prices.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/intraday/v1/intraday_prices.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xef\x01\n\x15IntradayPricesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"]\n\x16IntradayPricesResponse\x12\x43\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.intraday.v1.IntradayPrice\"m\n\rIntradayPrice\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\xa9\x01\n\x15IntradayPricesService\x12\x8f\x01\n\x0eIntradayPrices\x12=.systemathics.apis.services.intraday.v1.IntradayPricesRequest\x1a>.systemathics.apis.services.intraday.v1.IntradayPricesResponseb\x06proto3')



_INTRADAYPRICESREQUEST = DESCRIPTOR.message_types_by_name['IntradayPricesRequest']
_INTRADAYPRICESRESPONSE = DESCRIPTOR.message_types_by_name['IntradayPricesResponse']
_INTRADAYPRICE = DESCRIPTOR.message_types_by_name['IntradayPrice']
IntradayPricesRequest = _reflection.GeneratedProtocolMessageType('IntradayPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYPRICESREQUEST,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayPricesRequest)
  })
_sym_db.RegisterMessage(IntradayPricesRequest)

IntradayPricesResponse = _reflection.GeneratedProtocolMessageType('IntradayPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYPRICESRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayPricesResponse)
  })
_sym_db.RegisterMessage(IntradayPricesResponse)

IntradayPrice = _reflection.GeneratedProtocolMessageType('IntradayPrice', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYPRICE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayPrice)
  })
_sym_db.RegisterMessage(IntradayPrice)

_INTRADAYPRICESSERVICE = DESCRIPTOR.services_by_name['IntradayPricesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYPRICESREQUEST._serialized_start=290
  _INTRADAYPRICESREQUEST._serialized_end=529
  _INTRADAYPRICESRESPONSE._serialized_start=531
  _INTRADAYPRICESRESPONSE._serialized_end=624
  _INTRADAYPRICE._serialized_start=626
  _INTRADAYPRICE._serialized_end=735
  _INTRADAYPRICESSERVICE._serialized_start=738
  _INTRADAYPRICESSERVICE._serialized_end=907
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_sector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/static_data/v1/static_sector.proto\x12)systemathics.apis.services.static_data.v1\"Q\n\x13StaticSectorRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0e\n\x04\x63ode\x18\x02 \x01(\tH\x00\x12\x0f\n\x05level\x18\x03 \x01(\x05H\x00\x42\x07\n\x05value\"z\n\x14StaticSectorResponse\x12>\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.static_data.v1.Level\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"U\n\x05Level\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x12\n\ndefinition\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t2\xa7\x01\n\x13StaticSectorService\x12\x8f\x01\n\x0cStaticSector\x12>.systemathics.apis.services.static_data.v1.StaticSectorRequest\x1a?.systemathics.apis.services.static_data.v1.StaticSectorResponseb\x06proto3')



_STATICSECTORREQUEST = DESCRIPTOR.message_types_by_name['StaticSectorRequest']
_STATICSECTORRESPONSE = DESCRIPTOR.message_types_by_name['StaticSectorResponse']
_LEVEL = DESCRIPTOR.message_types_by_name['Level']
StaticSectorRequest = _reflection.GeneratedProtocolMessageType('StaticSectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATICSECTORREQUEST,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticSectorRequest)
  })
_sym_db.RegisterMessage(StaticSectorRequest)

StaticSectorResponse = _reflection.GeneratedProtocolMessageType('StaticSectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATICSECTORRESPONSE,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticSectorResponse)
  })
_sym_db.RegisterMessage(StaticSectorResponse)

Level = _reflection.GeneratedProtocolMessageType('Level', (_message.Message,), {
  'DESCRIPTOR' : _LEVEL,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.Level)
  })
_sym_db.RegisterMessage(Level)

_STATICSECTORSERVICE = DESCRIPTOR.services_by_name['StaticSectorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STATICSECTORREQUEST._serialized_start=108
  _STATICSECTORREQUEST._serialized_end=189
  _STATICSECTORRESPONSE._serialized_start=191
  _STATICSECTORRESPONSE._serialized_end=313
  _LEVEL._serialized_start=315
  _LEVEL._serialized_end=400
  _STATICSECTORSERVICE._serialized_start=403
  _STATICSECTORSERVICE._serialized_end=570
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xfc\x01\n\x12IntradayRsiRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"f\n\x13IntradayRsiResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayRsiData\"]\n\x0fIntradayRsiData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0b\n\x03rsi\x18\x03 \x01(\x01\x32\xb1\x01\n\x12IntradayRsiService\x12\x9a\x01\n\x0bIntradayRsi\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayRsiRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayRsiResponseb\x06proto3')



_INTRADAYRSIREQUEST = DESCRIPTOR.message_types_by_name['IntradayRsiRequest']
_INTRADAYRSIRESPONSE = DESCRIPTOR.message_types_by_name['IntradayRsiResponse']
_INTRADAYRSIDATA = DESCRIPTOR.message_types_by_name['IntradayRsiData']
IntradayRsiRequest = _reflection.GeneratedProtocolMessageType('IntradayRsiRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYRSIREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayRsiRequest)
  })
_sym_db.RegisterMessage(IntradayRsiRequest)

IntradayRsiResponse = _reflection.GeneratedProtocolMessageType('IntradayRsiResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYRSIRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayRsiResponse)
  })
_sym_db.RegisterMessage(IntradayRsiResponse)

IntradayRsiData = _reflection.GeneratedProtocolMessageType('IntradayRsiData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYRSIDATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayRsiData)
  })
_sym_db.RegisterMessage(IntradayRsiData)

_INTRADAYRSISERVICE = DESCRIPTOR.services_by_name['IntradayRsiService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYRSIREQUEST._serialized_start=307
  _INTRADAYRSIREQUEST._serialized_end=559
  _INTRADAYRSIRESPONSE._serialized_start=561
  _INTRADAYRSIRESPONSE._serialized_end=663
  _INTRADAYRSIDATA._serialized_start=665
  _INTRADAYRSIDATA._serialized_end=758
  _INTRADAYRSISERVICE._serialized_start=761
  _INTRADAYRSISERVICE._serialized_end=938
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_rsi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/daily_analytics/v1/daily_rsi.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xbb\x01\n\x0f\x44\x61ilyRsiRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"]\n\x10\x44\x61ilyRsiResponse\x12I\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily_analytics.v1.DailyRsiData\"K\n\x0c\x44\x61ilyRsiData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0b\n\x03rsi\x18\x03 \x01(\x01\x32\x9f\x01\n\x0f\x44\x61ilyRsiService\x12\x8b\x01\n\x08\x44\x61ilyRsi\x12>.systemathics.apis.services.daily_analytics.v1.DailyRsiRequest\x1a?.systemathics.apis.services.daily_analytics.v1.DailyRsiResponseb\x06proto3')



_DAILYRSIREQUEST = DESCRIPTOR.message_types_by_name['DailyRsiRequest']
_DAILYRSIRESPONSE = DESCRIPTOR.message_types_by_name['DailyRsiResponse']
_DAILYRSIDATA = DESCRIPTOR.message_types_by_name['DailyRsiData']
DailyRsiRequest = _reflection.GeneratedProtocolMessageType('DailyRsiRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYRSIREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyRsiRequest)
  })
_sym_db.RegisterMessage(DailyRsiRequest)

DailyRsiResponse = _reflection.GeneratedProtocolMessageType('DailyRsiResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYRSIRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyRsiResponse)
  })
_sym_db.RegisterMessage(DailyRsiResponse)

DailyRsiData = _reflection.GeneratedProtocolMessageType('DailyRsiData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYRSIDATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyRsiData)
  })
_sym_db.RegisterMessage(DailyRsiData)

_DAILYRSISERVICE = DESCRIPTOR.services_by_name['DailyRsiService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYRSIREQUEST._serialized_start=240
  _DAILYRSIREQUEST._serialized_end=427
  _DAILYRSIRESPONSE._serialized_start=429
  _DAILYRSIRESPONSE._serialized_end=522
  _DAILYRSIDATA._serialized_start=524
  _DAILYRSIDATA._serialized_end=599
  _DAILYRSISERVICE._serialized_start=602
  _DAILYRSISERVICE._serialized_end=761
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bars.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/tick_analytics/v1/tick_bars.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x95\x03\n\x0fTickBarsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x45\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.BarPrice\x12+\n\x08sampling\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\x07 \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x08 \x03(\t\x12\x0e\n\x06reject\x18\t \x03(\t\"\xa7\x01\n\x10TickBarsResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04open\x18\x02 \x01(\x01\x12\x0c\n\x04high\x18\x03 \x01(\x01\x12\x0b\n\x03low\x18\x04 \x01(\x01\x12\r\n\x05\x63lose\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x03\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04vwap\x18\x08 \x01(\x01*`\n\x08\x42\x61rPrice\x12\x19\n\x15\x42\x41R_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42\x41R_PRICE_TRADE\x10\x01\x12\x11\n\rBAR_PRICE_BID\x10\x02\x12\x11\n\rBAR_PRICE_ASK\x10\x03\x32\x9f\x01\n\x0fTickBarsService\x12\x8b\x01\n\x08TickBars\x12=.systemathics.apis.services.tick_analytics.v1.TickBarsRequest\x1a>.systemathics.apis.services.tick_analytics.v1.TickBarsResponse0\x01\x62\x06proto3')

_BARPRICE = DESCRIPTOR.enum_types_by_name['BarPrice']
BarPrice = enum_type_wrapper.EnumTypeWrapper(_BARPRICE)
BAR_PRICE_UNSPECIFIED = 0
BAR_PRICE_TRADE = 1
BAR_PRICE_BID = 2
BAR_PRICE_ASK = 3


_TICKBARSREQUEST = DESCRIPTOR.message_types_by_name['TickBarsRequest']
_TICKBARSRESPONSE = DESCRIPTOR.message_types_by_name['TickBarsResponse']
TickBarsRequest = _reflection.GeneratedProtocolMessageType('TickBarsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBARSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBarsRequest)
  })
_sym_db.RegisterMessage(TickBarsRequest)

TickBarsResponse = _reflection.GeneratedProtocolMessageType('TickBarsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBARSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBarsResponse)
  })
_sym_db.RegisterMessage(TickBarsResponse)

_TICKBARSSERVICE = DESCRIPTOR.services_by_name['TickBarsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BARPRICE._serialized_start=856
  _BARPRICE._serialized_end=952
  _TICKBARSREQUEST._serialized_start=279
  _TICKBARSREQUEST._serialized_end=684
  _TICKBARSRESPONSE._serialized_start=687
  _TICKBARSRESPONSE._serialized_end=854
  _TICKBARSSERVICE._serialized_start=955
  _TICKBARSSERVICE._serialized_end=1114
# @@protoc_insertion_point(module_scope)
